@@ -1,10 +1,10 @@
-from collections import namedtuple
 from urllib.parse import urlparse
 
 from .util import remove_prefix
 
 
 class DSN:
+    # pylint:disable=too-many-arguments
     def __init__(self, dsn="", scheme="", host="", port="", project_id="", token=""):
         self.str = dsn
         self.scheme = scheme
@@ -23,11 +23,17 @@ class DSN:
         return f"{self.scheme}://{self.host}:14318"
 
     @property
-    def otlp_addr(self):
+    def otlp_http_addr(self):
         if self.host == "uptrace.dev":
             return "https://otlp.uptrace.dev"
         return f"{self.scheme}://{self.host}:{self.port}"
 
+    @property
+    def otlp_grpc_addr(self):
+        if self.host == "uptrace.dev":
+            return "https://otlp.uptrace.dev:4317"
+        return f"{self.scheme}://{self.host}:{self.port}"
+
 
 def parse_dsn(dsn: str) -> DSN:
     if dsn == "":
