@@ -4,22 +4,26 @@ from socket import gethostname
 from typing import Optional
 
 import grpc
-from opentelemetry import trace, metrics
-from opentelemetry.sdk.trace import TracerProvider
-from opentelemetry.sdk.trace.export import BatchSpanProcessor
-
+from opentelemetry import metrics, trace
+from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import (
+    OTLPMetricExporter,
+)
+from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import (
+    OTLPSpanExporter,
+)
 from opentelemetry.sdk import metrics as sdkmetrics
 from opentelemetry.sdk.metrics import MeterProvider
 from opentelemetry.sdk.metrics.export import (
-    PeriodicExportingMetricReader,
     AggregationTemporality,
+    PeriodicExportingMetricReader,
 )
 from opentelemetry.sdk.resources import Attributes, Resource
-from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter
-from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import OTLPMetricExporter
+from opentelemetry.sdk.trace import TracerProvider
+from opentelemetry.sdk.trace.export import BatchSpanProcessor
 
 from .client import Client
-from .dsn import parse_dsn, DSN
+from .id_generator import UptraceIdGenerator
+from .dsn import DSN, parse_dsn
 
 logger = logging.getLogger(__name__)
 
@@ -39,14 +43,17 @@ def configure_opentelemetry(
     dsn="",
     service_name: Optional[str] = "",
     service_version: Optional[str] = "",
+    deployment_environment: Optional[str] = "",
     resource_attributes: Optional[Attributes] = None,
     resource: Optional[Resource] = None,
 ):
     """
     configure_opentelemetry configures OpenTelemetry to export data to Uptrace.
     By default it:
-       - creates tracer provider;
-       - registers OTLP span exporter.
+       - Creates tracer provider.
+       - Registers OTLP span exporter.
+       - Creates metrics provider.
+       - Registers OTLP metrics exporter.
     """
 
     global _CLIENT  # pylint: disable=global-statement
@@ -60,11 +67,24 @@ def configure_opentelemetry(
         dsn = parse_dsn(dsn)
     except ValueError as exc:
         # pylint:disable=logging-not-lazy
-        logger.warning("Uptrace is disabled: %s", exc)
+        logger.warning("invalid Uptrace DSN: %s (Uptrace is disabled)", exc)
         return
 
+    if dsn.token == "<token>" or dsn.project_id == "<project_id>":
+        logger.warning("dummy DSN detected: %s (Uptrace is disabled)", dsn)
+        return
+
+    if dsn.port == "14318":
+        logger.warning(
+            "uptrace-python uses OTLP/gRPC exporter, but got port %s", dsn.port
+        )
+
     resource = _build_resource(
-        resource, resource_attributes, service_name, service_version
+        resource,
+        resource_attributes,
+        service_name,
+        service_version,
+        deployment_environment,
     )
 
     _CLIENT = Client(dsn=dsn)
@@ -76,9 +96,8 @@ def _configure_tracing(
     dsn: DSN,
     resource: Optional[Resource] = None,
 ):
-    if trace._TRACER_PROVIDER is None:
-        provider = TracerProvider(resource=resource)
-        trace.set_tracer_provider(provider)
+    provider = TracerProvider(resource=resource, id_generator=UptraceIdGenerator())
+    trace.set_tracer_provider(provider)
 
     credentials = grpc.ssl_channel_credentials()
     exporter = OTLPSpanExporter(
@@ -139,6 +158,7 @@ def _build_resource(
     resource_attributes: Attributes,
     service_name: str,
     service_version: str,
+    deployment_environment: str,
 ) -> Resource:
     if resource:
         return resource
@@ -151,5 +171,7 @@ def _build_resource(
         attrs["service.name"] = service_name
     if service_version:
         attrs["service.version"] = service_version
+    if deployment_environment:
+        attrs["deployment.environment"] = deployment_environment
 
     return Resource.create(attrs)
