@@ -37,8 +37,9 @@ def test_trace_url():
 def test_dsn():
     dsn = uptrace.parse_dsn("http://localhost:14318")
     assert dsn.app_addr == "http://localhost:14318"
-    assert dsn.otlp_addr == "http://localhost:14318"
+    assert dsn.otlp_http_addr == "http://localhost:14318"
+    assert dsn.otlp_grpc_addr == "http://localhost:14318"
 
-    dsn = uptrace.parse_dsn("https://<key>@uptrace.dev/<project_id>")
+    dsn = uptrace.parse_dsn("https://<token>@uptrace.dev/<project_id>")
     assert dsn.app_addr == "https://app.uptrace.dev"
-    assert dsn.otlp_addr == "https://otlp.uptrace.dev"
+    assert dsn.otlp_grpc_addr == "https://otlp.uptrace.dev:4317"
